menu
tracker_coin_package package
documentation
tracker_coin_package.dart
tracker_coin_package.dart
dark_mode
light_mode
tracker_coin_package
library
Classes
CoinModel
CoinModel
is the model that we are handling inside our package. We will need this in order to have our
fetchCoin
method working.
TrackerCoinPackage
Properties
coinList
↔
List
<
CoinModel
>
This is the list that we will be displaying when using the package.
getter/setter pair
tracker_coin_package package
documentation
tracker_coin_package.dart
tracker_coin_package
package
Libraries
tracker_coin_package
tracker_coin_package library